==> laserturken_0.1-9.tar.gz: laserturken-0.1/src/opt/Laserturken/main.py <==
#!/usr/bin/python2.5
import sys
from PyQt4 import QtGui,QtCore
from PyQt4.phonon import Phonon
from laser import *

class MyForm(QtGui.QMainWindow):
        def __init__(self, parent=None):
                #build parent user interface
                QtGui.QWidget.__init__(self, parent)
                self.ui = Ui_MainWindow()
                self.ui.setupUi(self)
                self.ui.soundList.setCurrentRow(0)
                self.m_media = Phonon.MediaObject(self)
                audioOutput = Phonon.AudioOutput(Phonon.MusicCategory, self)
                audioOutput.setVolume(0.5)
                Phonon.createPath(self.m_media, audioOutput)
                #connect buttons
                QtCore.QObject.connect(self.ui.pushButton, QtCore.SIGNAL('clicked()'), self.playFart)
                
                self.farts={
                        "Kaos":"/opt/Laserturken/kaos.wav", "Polisen":"/opt/Laserturken/polisen.wav",
                        "Ta Han":"/opt/Laserturken/tahan.wav", "Tung":"/opt/Laserturken/klippa.wav",
                        "Bilen":"/opt/Laserturken/bilen.wav",
                        }
                
        def playFart(self):
                fart=self.farts[str(self.ui.soundList.currentItem().text())]
                self.m_media.setCurrentSource(Phonon.MediaSource(fart))
                self.m_media.play()
                        

if __name__ == "__main__":
        app = QtGui.QApplication(sys.argv)
        myapp = MyForm()
        myapp.show()
        sys.exit(app.exec_())

==> laserturken_0.2-0.tar.gz: laserturken-0.2/src/opt/Laserturken/main.py <==
#!/usr/bin/python2.5
import sys
from PyQt4 import QtGui,QtCore
from PyQt4.phonon import Phonon
from laser import *

class MyForm(QtGui.QMainWindow):
        def __init__(self, parent=None):
                #build parent user interface
                QtGui.QWidget.__init__(self, parent)
                self.ui = Ui_MainWindow()
                self.ui.setupUi(self)
                self.ui.soundList.setCurrentRow(0)
                self.m_media = Phonon.MediaObject(self)
                audioOutput = Phonon.AudioOutput(Phonon.MusicCategory, self)
                audioOutput.setVolume(0.5)
                Phonon.createPath(self.m_media, audioOutput)
                #connect buttons
                QtCore.QObject.connect(self.ui.pushButton, QtCore.SIGNAL('clicked()'), self.playFart)
                
                self.farts={
                        "Kaos":"/opt/Laserturken/kaos.wav", "Polisen":"/opt/Laserturken/polisen.wav",
                        "Ta Han":"/opt/Laserturken/tahan.wav", "Tung":"/opt/Laserturken/klippa.wav",
                        "Bilen":"/opt/Laserturken/bilen.wav", "Tuta":"/opt/Laserturken/tuta.wav", 
                        "Garanti":"/opt/Laserturken/garanti.wav", "Efternamn":"/opt/Laserturken/efternamn.wav",
                        }
                
        def playFart(self):
                fart=self.farts[str(self.ui.soundList.currentItem().text())]
                self.m_media.setCurrentSource(Phonon.MediaSource(fart))
                self.m_media.play()
                        

if __name__ == "__main__":
        app = QtGui.QApplication(sys.argv)
        myapp = MyForm()
        myapp.show()
        sys.exit(app.exec_())
